//
// C++ Implementation: kpgsqlexception
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgsqlexception.h"

KPGSqlException::KPGSqlException(const char* what, const QString & strSql)
 : std::runtime_error(what)
{
    m_strSql =  strSql; // TODO convert using connection codec !
}


